@@ -17,7 +17,8 @@
 
 import logging
 import os
-from xivo_ws.destination import GroupDestination, QueueDestination
+from xivo_ws.calleridmode import PrependCallerIDMode, OverwriteCallerIDMode, AppendCallerIDMode
+from xivo_ws.destination import GroupDestination, QueueDestination, UserDestination
 from xivo_ws.exception import WebServiceError, WebServiceRequestError
 from xivo_ws.objects.agent import Agent
 from xivo_ws.objects.confroom import ConfRoom
